#!/bin/bash
# ubuild.sh originally by Iguleder
# hacked to DEATH by 01micko
# Firmware download option big or cut from ibiblio.
# unattended wrapper by stemsee > nubuild.sh
# deblob-kernel-code libre-linux from Iguleder
# see /usr/share/doc/legal NO WARRANTY, NO responsibility accepted
CWD=`pwd`
Version="2.0"
timelimit=8
old=4.16.8
aufs_utils_git="http://git.code.sf.net/p/aufs/aufs-util"
#http://git.code.sf.net/p/aufs/aufs-util
FD=1
COMP="-comp xz"
# get date
today=`date +%m%y`
tmstamp=`date | cut -f2,3 -d ' ' | tr ' ' '-' | cut -f1 -d ':'`
#Compile and build
bldkern () {
if [[ -d ./aufs* ]]; then
	echo "This is not a clean kit."
	sleep 8
fi
if [ ! -f vanilla/linux-$kernel_version.tar.xz ]; then
# download the kernel
echo ${kernel_version##*-} | grep -q "rc"
[ "$?" -eq 0 ] && testing=testing || testing=
	if [[ ! -f vanilla/linux-$kernel_version.tar.xz ]]; then
	echo "Downloading the kernel sources"
	wget --no-check-certificate -P vanilla $kernel_mirror/linux-$kernel_version.tar.xz 
		if [[ $? -ne 0 ]]; then
			echo "Error: failed to download the kernel sources."
			exit 1
		fi
	fi
elif [ -f vanilla/linux-$kernel_version.tar.xz ]; then
echo "Kernel Sources already there!"
fi
# download Linux-libre scripts
if [ $LIBRE -eq 1 ]; then
	minor_version=${kernel_version##*.}
	for i in deblob-$kernel_major_version deblob-check; do
		if [ ! -f vanilla/$i ]; then
			wget --no-check-certificate -O vanilla/$i http://linux-libre.fsfla.org/pub/linux-libre/releases/LATEST-"$aufsv".N/$i
			if [ $? -ne 0 ]; then
				echo "Error: failed to download $i."
				exit 1
			fi
		fi
	done
fi
kernel_branch=`echo $latest | cut -f2 -d'.'`
# download Aufs
if [ ! -f vanilla/aufs$ver-$kernel_branch-git$today.tar.bz2 ]; then
	echo "Downloading the Aufs sources"
	if [ "$ver" -eq 4 ]; then
		git clone https://github.com/sfjro/aufs4-standalone aufs$ver-$kernel_branch-git$today
	elif [ "$ver" -eq 3 ]; then
		git clone https://git.code.sf.net/p/aufs/aufs3-standalone aufs-aufs$ver-standalone
	fi
	if [ $? -ne 0 ]; then
		echo "Error: failed to download the Aufs sources."
		sleep 4
		exit 1
	fi
	if [[ "$ver" = 3 ]]; then
		rename aufs-aufs$ver-standalone aufs"$ver"-"$kernel_branch"-git"$today" aufs-aufs$ver-standalone
	elif [[ "$ver" = 4 ]]; then
		rename master aufs"$ver"-"$kernel_branch"-git"$today" master
	fi
	cd aufs$ver-$kernel_branch-git$today
	if [ "$aufsv" ];then #new var for new kernels
		git checkout origin/aufs$ver.$kernel_branch
	else
		git checkout origin/aufs$ver.$kernel_branch
	fi
	if [ $? -ne 0 ]; then
		echo "Error: failed to download the Aufs sources."
		exit 1
	fi
	rm -rf .git
	cd ..
	echo "Creating the Aufs sources tarball"
	tar -c aufs$ver-$kernel_branch-git$today | bzip2 -9 > vanilla/aufs$ver-$kernel_branch-git$today.tar.bz2
else
	echo "Extracting the Aufs sources"
	tar xf vanilla/aufs$ver-$kernel_branch-git$today.tar.bz2 >> build.log 2>&1
	if [ $? -ne 0 ]; then
		echo "Error: failed to extract the Aufs sources."
		exit 1
	fi
fi
# patch Aufs
if [ -f aufs-allow-sfs.patch ];then #removed for K3.9 experiment
	echo "Patching the Aufs sources"
	patch -d aufs$ver-$kernel_branch-git$today -p1 < aufs-allow-sfs.patch >> build.log 2>&1
	if [ $? -ne 0 ]; then
		echo "Error: failed to patch the Aufs sources."
		exit 1
	fi
	cp aufs-allow-sfs.patch patches
fi
if [ -f aufs-kconfig.patch ];then #special for K3.9
	echo "Patching the Aufs sources"
	patch -d aufs$ver-$kernel_branch-git$today -p1 < aufs-kconfig.patch >> build.log 2>&1
	if [ $? -ne 0 ]; then
		echo "Error: failed to patch the Aufs sources for kconfig."
		exit 1
	fi
	cp aufs-kconfig.patch patches
fi
# extract the kernel
echo "Extracting the kernel sources"
tar xf vanilla/linux-$latest.tar.* >> build.log 2>&1
if [ $? -ne 0 ]; then
	echo "Error: failed to extract the kernel sources."
	exit 1
fi

cd linux-$kernel_version

echo "Adding Aufs to the kernel sources"
for i in kbuild base standalone mmap; do
	patch -N -p1 < ../aufs$ver-$kernel_branch-git$today/aufs$ver-$i.patch >> ../build.log 2>&1
	if [ $? -ne 0 ]; then
		echo "Error: failed to add Aufs to the kernel sources."
		exit 1
		echo "WARNING: failed to add some Aufs patches to the kernel sources."
		echo "Check it manually and either CRTL+C to bail or hit wait to go on"
		sleep 2
	fi
done
#aufspatch
cp -r ../aufs$ver-$kernel_branch-git$today/{fs,Documentation} .
cp ../aufs$ver-$kernel_branch-git$today/include/linux/aufs_type.h include/linux 2>/dev/null
cp ../aufs$ver-$kernel_branch-git$today/include/uapi/linux/aufs_type.h include/linux 2>/dev/null
[ -d ../aufs$ver-$kernel_branch-git$today/include/uapi ] && \
cp -r ../aufs$ver-$kernel_branch-git$today/include/uapi/linux/aufs_type.h include/uapi/linux
# deblob the kernel
if [ $LIBRE -eq 1 ]; then
	cd ..
	cp -r linux-$kernel_version linux-$kernel_version-orig
	cd linux-$kernel_version
	sh ../vanilla/deblob-$kernel_major_version 2>&1 | tee -a ../build.log
	cd ..
	diff -rupN linux-$kernel_version-orig linux-$kernel_version > patches/deblob.patch
	rm -rf linux-$kernel_version-orig
	cd linux-$kernel_version
fi
echo "Resetting the minor version number"
cp -f Makefile Makefile-orig
sed -i "s/^EXTRAVERSION =/EXTRAVERSION = $nwsfix/" Makefile
diff -up Makefile-orig Makefile > ../patches/extra-version.patch
rm Makefile-orig
	 cp kernel/printk/printk.c kernel/printk/printk.c.orig
	 sed -i s/'#define MAX_CMDLINECONSOLES 8'/'#define MAX_CMDLINECONSOLES 5'/ kernel/printk/printk.c
	 diff -up kernel/printk/printk.c.orig kernel/printk/printk.c > ../patches/less-consoles.patch
	 echo "Reducing the verbosity level"
	 cp -f include/linux/printk.h include/linux/printk.h.orig
	 sed -i s/'#define CONSOLE_LOGLEVEL_DEFAULT 7 \/\* anything MORE serious than KERN_DEBUG \*\/'/'#define CONSOLE_LOGLEVEL_DEFAULT 3 \/\* anything MORE serious than KERN_ERR \*\/'/ include/linux/printk.h
	 diff -up include/linux/printk.h.orig include/linux/printk.h > ../patches/lower-verbosity.patch
#patches
for patch in ../patches/*; do
	echo "Applying $patch"
	patch -p1 < $patch >> ../build.log 2>&1
	if [ $? -ne 0 ]; then
		echo "Error: failed to apply $patch on the kernel sources."
	fi
	cp $patch ../patches
done
#cleaningsrc
echo "Cleaning the kernel sources"
if [ -z "$DEB" ]; then
	make clean
	make mrproper
else
	make-kpkg clean
fi
find . -name '*.orig' -delete
find . -name '*.rej' -delete
find . -name '*~' -delete

[ ../DOTconfig ] && rm -f ../DOTconfig
case $car in
1) cp -af ../configs_extra_user/DOTconfig-64 ../DOTconfig;;
2) cp -af ../configs_extra_user/DOTconfig-pae ../DOTconfig;;
3) cp -af ../configs_extra_user/DOTconfig-nopae ../DOTconfig;;
esac
#Pause to configure
#configure
clear
echo -e "For unattended config of new kernels do nothing here!
For old kernel versions or other customisations enter 2 ... 

1. make olddefconfig
2. make menuconfig 
3. make oldconfig
$timelimit seconds\n: \c"
echo
read -t $timelimit kernelconfig
if [ ! -z "$kernelconfig" ]; then
	echo -e "\n You entered '$kernelconfig'"
else
	echo -e "\n TIME OUT\n Assume default."
	kernelconfig=3
fi
if [ "$arc" = 888 ]; then
	kernelconfig=2
fi
cp -f ../DOTconfig .config.old
cp -f ../DOTconfig .config
case $kernelconfig in
1) make olddefconfig;;
2) echo "Configure $arch kernel"
sleep 2
make menuconfig
if [ "$arc" = 888 ]; then
mv -f .config ../configs_extra_user/DOTconfig-64
mv -f ../configs_extra_user/DOTconfig-pae .config
echo "Configure pae kernel."
sleep 2
make menuconfig
mv -f .config ../configs_extra_user/DOTconfig-pae
sed -i "s/$nwsfix-64/$nwsfix-pae/" ../configs_extra_user/DOTconfig-pae
mv -f ../configs_extra_user/DOTconfig-nopae .config
echo "Configure nopae kernel."
sleep 2
make menuconfig
mv -f .config ../configs_extra_user/DOTconfig-nopae
sed -i "s/$nwsfix-64/$nwsfix-nopae/" ../configs_extra_user/DOTconfig-nopae
cp -f ../configs_extra_user/DOTconfig-64 .config
echo "Finished and continuing to compile 64 bit kernel."
fi
;;
3) make oldconfig;;
esac
echo
echo "Ok, kernel is configured. CTRL+C to quit"
cp -f .config ../configs_xtra/DOTconfig-$latest$kern-$today
sleep 2
[ ! -d ../dist/packages ] && mkdir -p ../dist/packages
#krnheads
if [ ! -d ../kernel_headers-$latest$nwsfix-$arch ]; then
	echo "Creating the kernel headers package"
	make headers_check >> ../build.log 2>&1
	make INSTALL_HDR_PATH=kernel_headers-$latest$nwsfix-$arch/usr headers_install >> ../build.log 2>&1
	find kernel_headers-$latest$nwsfix-$arch/usr/include \( -name .install -o -name ..install.cmd \) -delete
	mv kernel_headers-$latest$nwsfix-$arch ../
fi
cd ..
# build aufs-utils userspace modules
echo "Now to build the aufs-utils for userspace"
if [ ! -f vanilla/aufs-util${today}.tar.bz2 ];then
	git clone "$aufs_utils_git" aufs-util
	[ $? -ne 0 ] && echo "Failed to get aufs-util from git, do it manually. Kernel is compiled OK :)"
	cd aufs-util
	git branch -a | grep "aufs${ver}" | grep -v 'rcN' | cut -f2 -d'.' > /tmp/aufs-util-version #we go for stable only
	nowt=$(cat /tmp/aufs-util-version)
	if [[ -z "$nowt" ]]; then
		echo "9" > /tmp/aufs-util-version
	fi
	while read line
	  do 
	    if [[ "$line" -le "$kernel_branch" ]]; then 
			branch=$line
	    fi
	  done < /tmp/aufs-util-version
	#branch=$(cat /tmp/aufs-util-version)
	git checkout origin/aufs${ver}.$branch >> ../build.log 2>&1
	[ $? -ne 0 ] && echo "Failed to get aufs-util from git, do it manually. Kernel is compiled OK :)"
	# patch Makefile for static build
	echo "Patching aufs-util sources"
	cp -f Makefile Makefile.orig
	sed -i 's/-static //' Makefile
	rm ../patches/aufs-util-dynamic.patch
	diff -ru Makefile.orig Makefile > ../patches/aufs-util-dynamic.patch
	rm Makefile.orig
	patch -p1 < ../patches/aufs-util-dynamic.patch >> ../build.log 2>&1
	[ "$?" -ne 0 ] && echo "Failed to patch the aufs-util sources."
	rm -f ../patches/aufs-util-dynamic.patch
else
	echo "Extracting the Aufs-util sources"
	tar xf vanilla/aufs-util$today.tar.bz2 >> ../build.log 2>&1
		if [ $? -ne 0 ]; then
			echo "Error: failed to extract the aufs-util sources."
			exit 1
		fi	
	cd aufs-util	
fi
# see if fhsm is enabled in kernel config
grep -q 'CONFIG_AUFS_FHSM=y' ../linux-$latest/.config
[ "$?" -eq 0 ] && export MAKE=make || export MAKE="make BuildFHSM=no"
LinuxSrc="$CWD/kernel_headers-$latest$nwsfix-$arch"
export CPPFLAGS="-I $LinuxSrc/usr/include"
$MAKE >> ../build.log 2>&1
[ $? -ne 0 ] && echo "Failed to compile aufs-util, do it manually. Kernel is compiled OK :)"
make DESTDIR=$CWD/dist/packages/kernel-modules-$latest$nwsfix-$arch install >> ../build.log 2>&1 #needs absolute path
make clean >> ../build.log 2>&1
tar -c ../aufs-util ../vanilla/aufs-util$today.tar.bz2
if [[ "$arch" = "x86_64" ]];then
	[[ -d ../dist/packages/kernel-modules-$latest$nwsfix-$arch/usr/lib ]] && mv ../dist/packages/kernel-modules/usr/lib \
	../dist/packages/kernel-modules/usr/lib64
fi
echo "aufs-util is in dist"
cd ../
#krncompile
cd linux-$latest
echo "Compiling the kernel"
cores=`grep 'cpu cores' /proc/cpuinfo | cut -f3 -d' ' | tr '\n' ' ' | cut -f1 -d' '`
threads=$((cores * 3))
if [ "$cores" -ge 2 ]; then
	if [[ -z "$DEB" ]]; then
		make -j"$threads"
	elif [[ ! -z "$DEB" ]]; then
		mkdir ./debian
		fakeroot make-kpkg -j"$threads" --initrd --revision="$latest.$nwsfix" kernel_image kernel_headers
		make clean
		cd ..
		mksquashfs linux-"$latest" kernel_sources-"$latest".sfs -comp xz
	fi
else
	if [[ -z "$DEB" ]]; then
		make
	elif [[ ! -z "$DEB" ]]; then
		mkdir ./debian
		fakeroot make-kpkg --initrd --revision="$latest.$nwsfix" kernel_image kernel_headers
		make clean
		cd ..
		mksquashfs linux-"$latest" kernel_sources-"$latest".sfs -comp xz
	fi
fi
if [[ -z "$DEB" ]]; then
	if [[ ! -f arch/x86/boot/bzImage || ! -f System.map ]]; then
		echo "Error: failed to compile the kernel sources."
		exit 1
	fi
echo -e "Save this config file as ...?
optional path ... ?
eg DOTconfig-64 configs_extra_user
or DOTconfig-4.14.9-pae configs_extra
or leave empty for defaults
$timelimit seconds\n: \c"
echo
read -t $timelimit confname confdir
if [[ ! -z "$confname" ]]; then
	echo -e "\n You entered /$confdir/$confname"
else
	echo -e "\n TIME OUT\n Assume default."
	confname=DOTconfig-$kernel_version-$timestamp
	confdir=configs_extra
fi
cp .config ../"$confdir"/"$confname"
#krncompile
echo "Creating the kernel package"
make INSTALL_MOD_PATH=../dist/packages/kernel-modules-$latest$nwsfix-$arch modules_install >> ../build.log 2>&1
rm -f ../dist/packages/kernel-modules-$latest$nwsfix-$arch/lib/modules/${latest}$nwsfix/{build,source}
mkdir -p ../dist/packages/kernel-modules-$latest$nwsfix-$arch/boot
mkdir -p ../dist/packages/kernel-modules-$latest$nwsfix-$arch/etc/modules
cp .config ../dist/packages/kernel-modules-$latest$nwsfix-$arch/etc/modules/DOTconfig-$latest$nwsfix-$arch
cp arch/x86/boot/bzImage ../dist/packages/kernel-modules-$latest$nwsfix-$arch/boot/vmlinuz-$latest$nwsfix-$arch
cp System.map ../dist/packages/kernel-modules-$latest$nwsfix-$arch/boot/
cp ../dist/packages/kernel-modules-$latest$nwsfix-$arch/lib/modules/${latest}$nwsfix/{modules.builtin,modules.order} \
../dist/packages/kernel-modules-$latest$nwsfix-$arch/etc/modules/
#mv kernel-modules-$latest$nwsfix-$arch ../dist/packages/
	mv ../dist/packages/kernel-modules-$latest$nwsfix-$arch/boot/vmlinuz-$latest$nwsfix-$arch ../dist/packages/vmlinuz-$latest$nwsfix-"$arch"
	[[ -f ../dist/packages/kernel-modules-$latest$nwsfix-$arch/boot/bzImage ]] && rm -f ../dist/packages/kernel-modules-$latest$nwsfix-$arch/boot/bzImage
echo "Cleaning the kernel sources"
make clean >> ../build.log 2>&1
make prepare >> ../build.log 2>&1
cd $CWD
	#echo "Installing aufs-utils into kernel package"
	#cp -a dist/packages/kernel-modules/{etc,usr,sbin} \
	dist/packages/kernel-modules-$latest$nwsfix-$arch/
	#rm -rf dist/packages/kernel-modules
	if [[ "$firmdl" != s && "$firmdl" != b ]]; then
		cp -a /lib/firmware dist/packages/kernel-modules-$latest$nwsfix-$arch/lib/
	fi
	[[ "$firmdl" = s ]] && tar -xjf vanilla/firmware-140621-small.tar.bz2 -C dist/packages/kernel-modules-$latest$nwsfix-$arch/lib/
	[[ "$firmdl" = b ]] && tar -xjf vanilla/firmware-140621-big.tar.bz2 -C dist/packages/kernel-modules-$latest$nwsfix-$arch/lib/
	mksquashfs dist/packages/kernel-modules-$latest$nwsfix-$arch dist/packages/kernel-modules.sfs-"$latest""$nwsfix"-"$arch" $COMP
	rm -rf dist/packages/kernel-modules-$latest$nwsfix-$arch
	echo "Packaging huge-$latest$nwsfix-$arch kernel"
	cd dist/packages/
	tar -cjvf huge-$latest${nwsfix}-"$arch".tar.bz2 \
	vmlinuz-$latest$nwsfix-$arch kernel-modules.sfs-$latest$nwsfix-$arch
	md5sum huge-$latest${nwsfix}-"$arch".tar.bz2 > huge-$latest${nwsfix}-"$arch".tar.bz2.md5.txt
	echo "Huge kernel $latest$nwsfix-$arch/ is ready in dist"
	#rm -rf ../kernel_headers-$latest$nwsfix-$arch
	#rm -rf ../aufs-util
	#rm -rf ../linux_kernel*
fi
cd $CWD
clear
echo " Done!"
[ -f /usr/share/sounds/2barks.au ] && aplay /usr/share/sounds/2barks.au
}
mkkernsrc () {
	echo "Creating a kernel sources SFS" > build.log 2>&1
	mkdir -p kernel_sources-$latest$nwsfix-$arch/usr/src > build.log 2>&1
	mv linux-${latest}${nwsfix} kernel_sources-$latest$nwsfix-$arch/usr/src/linux > build.log 2>&1
	mkdir -p kernel_sources-${latest}${nwsfix}-$arch/lib/modules/${latest}${nwsfix}
if [ ! -f kernel_sources-$latest$nwsfix-$arch/usr/src/linux/include/linux/version.h ] ; then
	ln -s /usr/src/linux/include/generated/uapi/linux/version.h \
	 kernel_sources-$latest$nwsfix-$arch/usr/src/linux/include/linux/version.h
fi
	mkdir -p kernel_sources-$latest$nwsfix-$arch/lib/modules/${latest}$nwsfix > build.log 2>&1
	cd kernel_sources-$latest$nwsfix-$arch/lib/modules/${latest}$nwsfix/
	ln -s /usr/src/linux build > build.log 2>&1
	[ ! -f /usr/src/linux/include/linux/version.h ] && \
	ln -s /usr/src/linux/include/generated/uapi/linux/version.h usr/src/linux/include/linux/version.h  > build.log 2>&1
	ln -s /usr/src/linux source > build.log 2>&1
	cd $CWD
	cp -r kernel_headers-$latest$nwsfix-$arch/usr/include kernel_sources-$latest$nwsfix-$arch/usr/
	mksquashfs kernel_sources-$latest$nwsfix-$arch dist/packages/kernel_sources-$latest$nwsfix-"$arch".sfs $COMP -noappend > build.log 2>&1
	[[ ! -d debs ]] &&	mkdir debs
	[[ *.deb ]] && mv *.deb debs/
	[[ *.sfs ]] && mv *.sfs debs/
}
if [ "$1" = makesources ]; then
	[[ /tmp/sukkvars ]] && . /tmp/sukkvars
	mkkernsrc
	exit 0
fi
if [ "$1" = reset ]; then
	rm -f vanilla/linux-*
	rm -f vanilla/aufs*
	rm -rf dist/kernel_headers*
	rm -f /tmp/firmware-*
	rm -f /tmp/megatools*
	rm -f vanilla/deblob*
	rm /tmp/sukkvars
fi
cd "$CWD"
read -p "Press ENTER to begin, or 
'ctrl + c' then type './nubuild.sh reset' to start very clean." dummy
	echo -en "\033[1;35m""WARNING" #purple?
	echo -en "\033[0m" #reset
	echo "Cleaning."
	sleep 2
	echo "Please wait..."
	rm -rf ./{aufs*,linux*,kernel*,build.log*}
	rm -f build.log.bz2
	rm -f /tmp/aufs-util-version
	rm -f /tmp/sukkvars
	echo "Cleaning complete"
#fakeroot make-kpkg --initrd --revision="$latest-$nwsfix-$arch" kernel_image kernel_headers
echo "Please enter which kernel/s to build

e.g.    1) 64bit
        2) 32bit-pae
        3) 32bit-nopae
    or
      888) To reconfigure all 3 DOTconfig files and then build all kernels.
    or
        7) To build single modules or build kernel from kernel_sources-*.sfs!

e.g.   '1'  or  '2'  or  '3'  or  '12' or '23' or '13' or '123' 
	
	for debian system packages add 'deb' 
		e.g. '1 deb' '2 deb' or '3 deb' (can build only one kernel at a time)"

read arc DEB
echo "arc=$arc"
if [ -z "$arc" ]; then
	arc="123"
fi
if [ "$arc" = 7 ]; then
	cd sources
	./buildfromsrc
exit
fi
echo "$arc" 

mkdir -p dist/previouspkgs-"$today" 
if [ -d dist/packages* ]; then
	mv -f dist/packages* dist/previouspkgs-"$today" 
fi
echo "Please now enter the kernel version you would like this script to compile.
Current version setting is '$old' 
e.g.    4.14.9"
read latest
if [ -z "$latest" ]; then
	latest="$old"
fi
echo "'$latest'" 
nafsv=`echo $latest | cut -f1,2 -d'.'`
export nafsv
ver=`echo $latest | cut -f1 -d'.'`
export ver
kernel_version=$latest
export latest
kernel_major_version=$nafsv
kernel_branch=`echo $latest | cut -f2 -d'.'`
kernel_mirror="https://cdn.kernel.org/pub/linux/kernel/v$ver.x/"
aufs_git=git://github.com/sfjro/aufs$ver-standalone.git
echo
echo "You can change the custom name on the kernel. Better not use minus symbol -.
Presently it is '$olsfix'. For debian system use lowercase only."
read nwsfix
if [ -z "$nwsfix" ]; then
	nwsfix="$olsfix"
fi
echo "$nwsfix" 
nwsfix="$nwsfix"
clear
echo "To download firmware enter b or s,
big=16.6M | small=9.7M
to NOT download press enter."
read firmdl
case $firmdl in
	b)  wget -t0 -c http://distro.ibiblio.org/puppylinux/firmware/firmware-140621-big.tar.bz2 -P vanilla/;;
	s)  wget -t0 -c http://distro.ibiblio.org/puppylinux/firmware/firmware-140621-cut.tar.bz2 -P vanilla/;;
	*) ;;
esac
echo
echo "This option removes non-free frimware from kernel.
Deblob kernel? 'y' or Enter for 'no'"
read LIBRE
case $LIBRE in
	y) LIBRE=1;;
	n) LIBRE=0;;
	*) LIBRE=0;;
esac
# depcheck
echo "Dependency check..."
if [ ! -z "$DEB" ]; then
	echo "For deb these packages must be installed:
	fakeroot build-essential kernel-package libssl-dev git ncurses-dev bc
	linux-headers-amd64 or linux-headers-x86 or i386 i686 etc.
	Install will be attempted now if you press 'i'"
	read install
	if [[ "$install" = i ]]; then
		doit=`busybox which apt-get`
		if [[ ! -z "$doit" ]]; then
			sudo apt-get --update
			sudo apt-get -y install fakeroot build-essential kernel-package git ncurses-dev linux-headers-* libssl-dev bc -y
		else
			go=`busybox which slapt-get`
			if [[ ! -z "$go" ]]; then
				slapt-get -u
				slapt-get --install fakeroot bc
			fi
		fi
	fi
	if fakeroot --version &>/dev/null
		then echo -e "\033[1;32m""fakeroot is installed" #green 
	else echo -e "\033[1;31m""fakeroot might not be installed""\033[0m" #red
	fi
fi
if git --version &>/dev/null
	then echo -e "\033[1;32m""git is installed" #green 
else echo -e "\033[1;31m""git is not installed""\033[0m" && exit #red
fi
if gcc --version &>/dev/null
	then echo -e "\033[1;32m""gcc is installed" 
else
   echo -e "\033[1;31m""gcc is not installed""\033[0m" && exit
fi
MKSQ="$(busybox which mksquashfs)"
if [ "$MKSQ" ]
	then 
   echo -e "\033[1;32m""mksquashfs is installed"
else #yellow
   echo -e "\033[1;30m""mksquashfs is not installed but you can continue"
fi
echo -e "\033[0m" #reset to original
xis=$arc
case $xis in
	1) arch=x86_64
		kern=64
		olsfix=-PuPpY-$kern;;
	2) arch=i686
		kern=32-pae
		olsfix=-PuPpY-$kern;;
	3) arch=i486
		kern=32-nopae
		olsfix=-PuPpY-$kern;;
	888) continue;;
esac
case $arc in
	1|2|3) car=$arc
		bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
	fi
	rename packages packages$kern dist/packages
	;;
	
	12|21) car=1
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages$kern dist/packages
	fi
	car=2
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages$kern dist/packages
	fi;;
	
	13|31)  car=1
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages64 dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi;;
	
	23|32) car=2
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-pae dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi
	;;
	
	123|321|213|312|132|231) car=1
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages64 dist/packages
	fi
	car=2
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages32-pae dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi
	;;
	
	888)	bldkern
	car=1
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages64 dist/packages
		unset arc
	fi
	car=2
	bldkern
	if [[ -z "$DEB" ]]; then 
		mkkernsrc
		rename packages packages32-pae dist/packages
	fi
	car=3
	bldkern
	if [[ -z "$DEB" ]]; then
		mkkernsrc
		rename packages packages32-nopae dist/packages
	fi
	;;
		
	7) cd dist/sources
	./buildfromsrc
	;;
esac
cd "$CWD"
#rm -f dist/kernel_headers* > build.log 2>&1
mv -f /tmp/firmware-*-*.tar.bz2 vanilla/ > build.log 2>&1
#rm -rf kernel_sources-* > build.log 2>&1
#rm -rf aufs* > build.log 2>&1
rm -f DOTconfig
dodo=`grep -e 'FatDog' -e 'fatdog' -e 'quirky' -e 'Quirky' -e 'lighthouse' -e 'Lighthouse' -e 'Xenial' -e 'xenial' /etc/DISTRO_SPECS`
if [ -z "$dodo" ]; then
echo "Compilation has finished.
Do you want the script to upgrade your working kernel and modules?
'y' or 'n'"
read upgrade
case $upgrade in
n) exit 0;;
y) case $arc in
		1) kern=64;;
		2) kern=32-pae;;
		3) kern=32-nopae;;
	esac;;
esac
	if [[ ! -z "$DEB" ]]; then
		for file in linux-image-"$latest"$nwsfix-$arch.deb linux-headers-"$latest"$nwsfix-$arch.deb
		do
			dpkg -i "$file"
			mkdir -p /tmp/modules/lib
			cp -r /lib/{modules,firmware} /tmp/modules/lib
			mksquashfs /tmp/modules /live/image/live/modules.squashfs
			sync
		done
	else
		echo "Install new kernel (vmlinuz) and kernel-modules.sfs where?
		enter path  e.g. /mnt/sda6/Tahr/"
		read inst
		if [[ -e "$inst"vmlinuz ]]; then
			. /etc/DISTRO_SPECS
			rename "$DISTRO_ZDRVSFS" "$DISTRO_ZDRVSFS"-bak "$inst""$DISTRO_ZDRVSFS"
			rename vmlinuz vmlinuz-bak "$inst"vmlinuz
			cp -f dist/packages"$kern"/vmlinuz-$latest$nwsfix-$arch "$inst"vmlinuz
			cp -f dist/packages"$kern"/kernel-modules.sfs-$latest$nwsfix-$arch "$inst""$DISTRO_ZDRVSFS"
			sync
			rox "$inst"
			echo "All Done!"
		fi
	fi
fi
exit
###the end###
